@@ -1,8 +1,11 @@
 list.GEOmap<-function(MAP, SEL=1)
   {
 ########   return a GEOmap list to a normal GEOmap with points as one long vector
-    ########  
-    if(missing(SEL)) SEL = 1:length(MAP$STROKES$index)
+    ########
+
+    N = length(MAP$LL)
+    
+    if(missing(SEL)) SEL = 1:N 
     
     NEWMAP = list(STROKES = list(nam = NULL, num = NULL, index = NULL,
                     col = NULL, style = NULL, code = NULL, LAT1 = NULL, LAT2 = NULL,
@@ -16,6 +19,33 @@ list.GEOmap<-function(MAP, SEL=1)
 NEWMAP$POINTS$lon=NULL
 NEWMAP$POINTS$lat=NULL
 
+    if(is.null(MAP$STROKES))
+      {
+        LON2=LON1=LAT2=LAT1=vector(); 
+        for(i in 1:N)
+          {
+            LAT1[i] = min(MAP$LL[[i]]$lat)
+               LAT2[i]  = max(MAP$LL[[i]]$lat)
+               LON1[i]  = min(MAP$LL[[i]]$lon)
+               LON2[i]  = max(MAP$LL[[i]]$lon)
+
+
+          }
+
+        
+        MAP$STROKES = 
+          list(nam =paste("m",1:N, sep="")  ,
+               num =unlist(lapply(MAP$LL, length)) ,
+               index = NULL,
+               col = rep("black", N),
+               style = rep(2, N),
+               code = rep("o", N),
+               LAT1 = LAT1,
+               LAT2 = LAT2,
+               LON1 = LON1,
+               LON2 = LON2)
+        
+      }
     
     for(i in SEL)
       {
