@@ -1,7 +1,7 @@
 maps2GEOmap<-function(zz, wx=1, mapnam="temp" )
 {
   if(missing(mapnam)) mapnam="temp"
-  if(missing(wx)) wx = which(is.na(zz$x))
+  if(missing(wx)) wx = c(which(is.na(zz$x))) 
 
   
   #########   convert maps information from a maps data base to a GEOmap data
@@ -15,18 +15,31 @@ maps2GEOmap<-function(zz, wx=1, mapnam="temp" )
   Kcol = vector()
 
   a1 = 1
-  n  = length(wx)
-  start = 0
+  
+   start = 0
+
+  if(length(wx)<1)
+    {
+ibegs = c(1)
+iends = c(length(zz$x))
+}
+  else
+  {
+ibegs = c(1, wx+1)
+iends = c(wx-1, length(zz$x))
+  }
+  
+  n = length(ibegs)
   for(i in 1:n)
     {
-      i1 = a1
-      i2 = wx[i]-1
+      i1 = ibegs[i]
+      i2 = iends[i]
      ## print(c(i1, i2))
       el = length(i1:i2)
       Kx = c(Kx, zz$x[i1:i2])
       Ky = c(Ky, zz$y[i1:i2])
 
-      a1 = wx[i]+1
+      
       Knum[i] = el
       Kindex[i] =  start
       start = start + el
@@ -38,21 +51,6 @@ maps2GEOmap<-function(zz, wx=1, mapnam="temp" )
       
     }
 
-  i1 = a1
-  i2 = length( zz$x)
-  Kx = c(Kx, zz$x[i1:i2])
-  Ky = c(Ky, zz$y[i1:i2])
-  el = length(i1:i2)
-  i = i+1
-  Knum[i] = el
-  Kindex[i] =  start
-  start = start + el
-  
-  Knam[i] = paste(mapnam, i, sep="_")
-  Kstyle[i] = 2
-  Kcode[i] =  'o'
-  Kcol[i] =  'black'
-
     NEWMAP = list(STROKES = list(nam =Knam , num =Knum , index =Kindex ,
                   col = Kcol, style = Kstyle, code = Kcode, LAT1 = NULL, LAT2 = NULL,
                   LON1 = NULL, LON2 = NULL), POINTS = list(lat = Ky,
